@@ -1,6 +1,5 @@
 import requests
 from requests import Response
-from tldextract import TLDExtract
 from tldextract.tldextract import ExtractResult
 from tweepy.models import User
 from botometer import Botometer
@@ -9,8 +8,8 @@ from sourceRank.models.source_credibility_models import (SuffixRankDoc, OpenRank
                                                          WhoisAnalysisDoc, TwitterRankAnalysisDoc,
                                                          TwitterCredibilityDoc)
 from sourceRank.helper.country_domain_list import top_level_country_domains
-from sourceRank.helper.settings import logger
-from sourceRank.helper.utils import compute_importance_from_exponential_distribution
+from sourceRank.helper.settings import logger, default_field
+from sourceRank.helper.utils import compute_importance_from_exponential_distribution, relevance_mapping, parse_url
 from sourceRank.connectors.news_api_connector import NewsAPIConnector
 from sourceRank.connectors.twitter_api_connector import TwitterConnector
 
@@ -36,17 +35,7 @@ class SourceCredibilityAnalysis(object):
 
     @staticmethod
     def parse_url(url: str) -> ExtractResult:
-        tld_res: ExtractResult = ExtractResult(
-            domain="", subdomain="", suffix="")
-        try:
-            tld_extract_obj: TLDExtract = TLDExtract(
-                include_psl_private_domains=True)
-            tld_res: ExtractResult = tld_extract_obj(
-                url=url, include_psl_private_domains=True)
-
-        except Exception as e:
-            logger.error(e)
-        return tld_res
+        return parse_url(url=url)
 
     def get_open_page_rank(self, domain: str) -> Response:
         response: Response = Response()
@@ -74,6 +63,39 @@ class SourceCredibilityAnalysis(object):
             logger.error(e)
         return response
 
+    @staticmethod
+    def get_whois_rank(whois_data) -> float:
+        rank: float = 0.0
+        try:
+            # 1. Relevance age
+            relevance_by_age: float = relevance_mapping(
+                x=whois_data.get("estimatedDomainAge"))
+
+            # 2. Registered domain
+            if whois_data.get("domainName") != default_field:
+                x_domain: float = 100
+            else:
+                x_domain: float = 1
+
+            relevance_by_domain: float = relevance_mapping(
+                    x=x_domain)
+
+            # 3. Registered country
+            if whois_data.get("registryData").get("registrant").get("country") != default_field:
+                x_country: float = 100
+            else:
+                x_country: float = 1
+
+            relevance_by_country: float = relevance_mapping(
+                x=x_country)
+
+            total_relevance: float = float((relevance_by_age + relevance_by_country + relevance_by_domain) / 3)
+            rank: float = round(total_relevance, 3)
+
+        except Exception as e:
+            logger.error(e)
+        return rank
+
     def get_whois_analysis(self, domain: str) -> WhoisAnalysisDoc:
         whois_analysis: WhoisAnalysisDoc = object.__new__(WhoisAnalysisDoc)
         try:
@@ -83,8 +105,9 @@ class SourceCredibilityAnalysis(object):
             # If the result is fine
             if response_whois.status_code == 200:
                 whois_data: dict = response_whois.json().get("WhoisRecord", {})
+                rank: float = self.get_whois_rank(whois_data=whois_data)
                 whois_analysis: WhoisAnalysisDoc = WhoisAnalysisDoc(
-                    whois_data)
+                    whois_data=whois_data, analysed=True, rank=rank)
 
         except Exception as e:
             logger.error(e)
@@ -136,7 +159,7 @@ class SourceCredibilityAnalysis(object):
             rank: float = round(compute_importance_from_exponential_distribution(
                 x=importance), 1)
             suffix_analysis: SuffixRankDoc = SuffixRankDoc(
-                suffix=suffix, importance=importance, rank=rank)
+                suffix=suffix, importance=importance, rank=rank, analysed=True)
         except Exception as e:
             logger.error(e)
         return suffix_analysis
@@ -177,7 +200,8 @@ class SourceCredibilityAnalysis(object):
                 language=candidate.language,
                 country_code=candidate.country,
                 importance=importance,
-                rank=rank)
+                rank=rank,
+                analysed=candidate.analysed)
         except Exception as e:
             logger.error(e)
         return category_analysis
