@@ -11,7 +11,7 @@ class SuffixRankDoc(object):
 
 
 class OpenRankDoc(object):
-    def __init__(self, domain: str, page_rank_decimal: float = 0.0, rank: float = 0.0,
+    def __init__(self, domain: str = "", page_rank_decimal: float = 0.0, rank: float = 0.0,
                  last_updated: str = "", analysed: bool = True):
         self.domain: str = domain
         self.page_rank_decimal: float = page_rank_decimal
@@ -56,25 +56,25 @@ class WhoisAnalysisDoc(object):
     def __init__(self, whois_data: dict, rank: float = 0.0, analysed: bool = False):
         self.domain_name: str = whois_data.get("domainName", default_field)
         self.created_date: str = get_str_datetime_from_non_formatted_str(
-            str_datetime=whois_data.get("registryData").get(
+            str_datetime=whois_data.get("registryData", {}).get(
                 "createdDate", default_field))
         self.updated_date: str = get_str_datetime_from_non_formatted_str(
-            str_datetime=whois_data.get("registryData").get(
+            str_datetime=whois_data.get("registryData", {}).get(
                 "updatedDate", default_field))
         self.expired_date: str = get_str_datetime_from_non_formatted_str(
-            str_datetime=whois_data.get("registryData").get(
+            str_datetime=whois_data.get("registryData", {}).get(
                 "updatedDate", default_field))
-        self.organization: str = whois_data.get("registryData").get("registrant").get(
+        self.organization: str = whois_data.get("registryData", {}).get("registrant", {}).get(
             "organization", default_field)
-        self.street: str = whois_data.get("registryData").get("registrant").get(
+        self.street: str = whois_data.get("registryData", {}).get("registrant", {}).get(
             "street1", default_field)
-        self.city: str = whois_data.get("registryData").get("registrant").get(
+        self.city: str = whois_data.get("registryData", {}).get("registrant", {}).get(
             "city", default_field)
-        self.state: str = whois_data.get("registryData").get("registrant").get(
+        self.state: str = whois_data.get("registryData", {}).get("registrant", {}).get(
             "state", default_field)
-        self.postal_code: str = whois_data.get("registryData").get("registrant").get(
+        self.postal_code: str = whois_data.get("registryData", {}).get("registrant", {}).get(
             "postalCode", default_field)
-        self.country_code: str = whois_data.get("registryData").get("registrant").get(
+        self.country_code: str = whois_data.get("registryData", {}).get("registrant", {}).get(
             "countryCode", default_field)
         self.country: str = get_country_name_by_code(
             country_code=self.country_code)
